django-oauthost documentation
=============================

*django-oauthost is a reusable application for Django, introducing OAuth2 server functionality.*

It allows to guard your applications views with OAuth 2.0 in quite a trivial way.


Requirements
------------

1. Python 2.7+, 3.2+
2. Django 1.4+
3. Auth Django contrib package
4. South 0.7.1+ for Django (required for version upgrades)
5. Django Admin site contrib package (for oauthost data manipulation).


Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    helpers
    references


Get involved into django-oauthost
---------------------------------

**Submit issues.** If you spotted something weird in application behavior or want to propose a feature you can do
that at https://github.com/idlesign/django-oauthost/issues

**Write code.** If you are eager to participate in application development, fork it
at https://github.com/idlesign/django-oauthost, write your code, whether it should be a bugfix or a feature
implementation, and make a pull request right from the forked project page.

**Translate.** If want to translate the application into your native language use Transifex:
https://www.transifex.net/projects/p/django-oauthost/.

**Spread the word.** If you have some tips and tricks or any other words in mind that you think might be of interest
for the others — publish it.


Also
----

If the application is not what you want for site navigation, you might be interested in considering
other choices at http://djangopackages.com/grids/g/oauth-servers/